@@ -86,8 +86,10 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(Touch),
             whole_stream_command(Cpy),
             whole_stream_command(Date),
+            whole_stream_command(DateListTimeZone),
             whole_stream_command(DateNow),
-            whole_stream_command(DateUTC),
+            whole_stream_command(DateToTable),
+            whole_stream_command(DateToTimeZone),
             whole_stream_command(DateFormat),
             whole_stream_command(Cal),
             whole_stream_command(Mkdir),
@@ -120,6 +122,8 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(Autoview),
             whole_stream_command(Table),
             // Text manipulation
+            whole_stream_command(Hash),
+            whole_stream_command(HashBase64),
             whole_stream_command(Split),
             whole_stream_command(SplitColumn),
             whole_stream_command(SplitRow),
@@ -213,6 +217,7 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(AutoenvTrust),
             whole_stream_command(AutoenvUnTrust),
             whole_stream_command(Math),
+            whole_stream_command(MathAbs),
             whole_stream_command(MathAverage),
             whole_stream_command(MathEval),
             whole_stream_command(MathMedian),
@@ -264,6 +269,7 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(RandomUUID),
             whole_stream_command(RandomInteger),
             whole_stream_command(RandomDecimal),
+            whole_stream_command(RandomChars),
             // Path
             whole_stream_command(PathBasename),
             whole_stream_command(PathCommand),
