@@ -95,15 +95,7 @@ async fn do_(
 
     block.set_redirect(block_redirection);
 
-    let result = run_block(
-        &block,
-        &mut context,
-        input,
-        &scope.it,
-        &scope.vars,
-        &scope.env,
-    )
-    .await;
+    let result = run_block(&block, &mut context, input, scope).await;
 
     if ignore_errors {
         // To properly ignore errors we need to redirect stderr, consume it, and remove
@@ -125,11 +117,12 @@ async fn do_(
 #[cfg(test)]
 mod tests {
     use super::Do;
+    use super::ShellError;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(Do {})
+        Ok(test_examples(Do {})?)
     }
 }
