@@ -67,11 +67,12 @@ async fn prepend(
 #[cfg(test)]
 mod tests {
     use super::Prepend;
+    use super::ShellError;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(Prepend {})
+        Ok(test_examples(Prepend {})?)
     }
 }
