@@ -16,6 +16,7 @@ pub struct RemoveArgs {
     pub trash: Tagged<bool>,
     #[allow(unused)]
     pub permanent: Tagged<bool>,
+    pub force: Tagged<bool>,
 }
 
 #[async_trait]
@@ -37,6 +38,7 @@ impl WholeStreamCommand for Remove {
                 Some('p'),
             )
             .switch("recursive", "delete subdirectories recursively", Some('r'))
+            .switch("force", "suppress error when no file", Some('f'))
             .rest(SyntaxShape::Pattern, "the file path(s) to remove")
     }
 
@@ -69,6 +71,11 @@ impl WholeStreamCommand for Remove {
                 example: "rm --permanent file.txt",
                 result: None,
             },
+            Example {
+                description: "Delete a file, and suppress errors if no file is found",
+                example: "rm --force file.txt",
+                result: None,
+            }
         ]
     }
 }
@@ -93,11 +100,12 @@ async fn rm(args: CommandArgs, registry: &CommandRegistry) -> Result<OutputStrea
 #[cfg(test)]
 mod tests {
     use super::Remove;
+    use super::ShellError;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(Remove {})
+        Ok(test_examples(Remove {})?)
     }
 }
