@@ -112,8 +112,8 @@ fn action(input: &Value, tag: impl Into<Tag>) -> Result<Value, ShellError> {
 mod tests {
     use super::ShellError;
     use super::{action, SubCommand};
-    use nu_plugin::test_helpers::value::string;
     use nu_source::Tag;
+    use nu_test_support::value::string;
 
     #[test]
     fn examples_work_as_expected() -> Result<(), ShellError> {
