@@ -48,12 +48,13 @@ async fn to_tsv(args: CommandArgs, registry: &CommandRegistry) -> Result<OutputS
 
 #[cfg(test)]
 mod tests {
+    use super::ShellError;
     use super::ToTSV;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(ToTSV {})
+        Ok(test_examples(ToTSV {})?)
     }
 }
