@@ -1,3 +1,5 @@
+use nu_test_support::fs::Stub::EmptyFile;
+use nu_test_support::playground::Playground;
 use nu_test_support::{nu, pipeline};
 
 #[test]
@@ -8,7 +10,6 @@ fn creates_the_resulting_string_from_the_given_fields() {
         open cargo_sample.toml
             | get package
             | format "{name} has license {license}"
-            | echo $it
         "#
     ));
 
@@ -22,7 +23,6 @@ fn given_fields_can_be_column_paths() {
         r#"
         open cargo_sample.toml
             | format "{package.name} is {package.description}"
-            | echo $it
         "#
     ));
 
@@ -36,9 +36,31 @@ fn can_use_variables() {
         r#"
         open cargo_sample.toml
             | format "{$it.package.name} is {$it.package.description}"
-            | echo $it
         "#
     ));
 
     assert_eq!(actual.out, "nu is a new type of shell");
 }
+
+#[test]
+fn format_filesize_works() {
+    Playground::setup("format_filesize_test_1", |dirs, sandbox| {
+        sandbox.with_files(vec![
+            EmptyFile("yehuda.txt"),
+            EmptyFile("jonathan.txt"),
+            EmptyFile("andres.txt"),
+        ]);
+
+        let actual = nu!(
+            cwd: dirs.test(), pipeline(
+            r#"
+                ls
+                | format filesize size KB
+                | get size
+                | first
+            "#
+        ));
+
+        assert_eq!(actual.out, "0.01 KB");
+    })
+}
